==> discover-5.11.4.tar.xz: discover-5.11.4/discover/org.kde.discover.desktop.cmake <==
[Desktop Entry]
Name=Discover
Name[ar]=استكشف
Name[ast]=Discover
Name[ca]=Discover
Name[ca@valencia]=Discover
Name[da]=Opdagelse
Name[de]=Discover
Name[el]=Discover
Name[en_GB]=Discover
Name[es]=Discover
Name[et]=Avastusretk
Name[eu]=Discover
Name[fi]=Discover
Name[fr]=Discover
Name[gl]=Descubrir
Name[he]=מרכז התוכנות Discover
Name[hu]=Discover
Name[ia]=Discoperi
Name[id]=Discover
Name[it]=Discover
Name[ko]=발견
Name[nl]=Ontdekken
Name[nn]=Oppdag
Name[pa]=ਖੋਜ
Name[pl]=Odkrywca
Name[pt]=Discover
Name[pt_BR]=Discover
Name[ru]=Discover
Name[sk]=Objaviť
Name[sl]=Programsko središče
Name[sr]=Oткривач
Name[sr@ijekavian]=Oткривач
Name[sr@ijekavianlatin]=Otkrivač
Name[sr@latin]=Otkrivač
Name[sv]=Upptäck
Name[tr]=Keşfet
Name[uk]=Discover
Name[x-test]=xxDiscoverxx
Name[zh_CN]=发现者
Name[zh_TW]=Discover
MimeType=@DesktopMimeType@
Exec=@DesktopExec@
Icon=plasmadiscover
Type=Application
X-DocPath=plasma-discover/index.html
InitialPreference=5
NoDisplay=@DesktopNoDisplay@
GenericName=Software Center
GenericName[ar]=مركز برمجيّات
GenericName[ca]=Centre de programari
GenericName[ca@valencia]=Centre de programari
GenericName[cs]=Centrum softwaru
GenericName[da]=Softwarecenter
GenericName[de]=Programmverwaltung
GenericName[el]=Κέντρο λογισμικού
GenericName[en_GB]=Software Centre
GenericName[es]=Centro de software
GenericName[et]=Tarkvarakeskus
GenericName[eu]=Software gunea
GenericName[fi]=Sovellusvalikoima
GenericName[fr]=Logithèque
GenericName[gl]=Centro de Software
GenericName[he]=מרכז התוכנות
GenericName[hu]=Szoftverközpont
GenericName[id]=Pusat Perangkat Lunak
GenericName[it]=Software Center
GenericName[ko]=소프트웨어 센터
GenericName[nb]=Programvaresenter
GenericName[nl]=Softwarecentrum
GenericName[nn]=Programvaresenter
GenericName[pa]=ਸਾਫਟਵੇਅਰ ਸੈਂਟਰ
GenericName[pl]=Ośrodek programów
GenericName[pt]=Centro de Aplicações
GenericName[pt_BR]=Central de aplicativos
GenericName[ru]=Центр программ
GenericName[sk]=Softwareové centum
GenericName[sl]=Programsko središče
GenericName[sr]=Софтверски центар
GenericName[sr@ijekavian]=Софтверски центар
GenericName[sr@ijekavianlatin]=Softverski centar
GenericName[sr@latin]=Softverski centar
GenericName[sv]=Programvarucentral
GenericName[tr]=Yazılım Merkezi
GenericName[uk]=Центр програм
GenericName[x-test]=xxSoftware Centerxx
GenericName[zh_CN]=软件中心
GenericName[zh_TW]=軟體中心
Categories=Qt;KDE;System;
Keywords=program;software;repository;package;install;remove;update;apps;applications;
Keywords[ar]=برنامج;برمجيّة;برمجية;مستودع;حزمة;تثبيت;إزالة;ازالة;تحديث;تطبيقات;تطبيق;
Keywords[ca]=programa;programari;repositori;paquet;instal·la;suprimeix;actualitza;apps;aplicacions;
Keywords[ca@valencia]=programa;programari;repositori;paquet;instal·la;suprimeix;actualitza;apps;aplicacions;
Keywords[cs]=program;software;repozitář;balíček;instalovat;odstranit;aktualizovat;programy;aplikace;
Keywords[da]=program;software;softwarekilde;repository;pakke;installer;fjern;opdater;apps;applikationer;
Keywords[de]=Programm;Software;Archiv;Repository;Paket;Installieren;Entfernen;Aktualisieren;Programme;Anwendungen;
Keywords[el]=πρόγραμμα;λογισμικό;αποθετήριο;πακέτο;εγκατάσταση;αφαίρεση;ενημέρωση;εφαρμογές;
Keywords[en_GB]=program;software;repository;package;install;remove;update;apps;applications;
Keywords[es]=programa;software;repositorio;paquete;instalar;eliminar;actualizar;apps;aplicaciones;
Keywords[et]=programm,rakendus,tarkvara,hoidla,pakk,pakett,paigaldamine,installimine,eemaldamine,uuendamine,rakendused,äpid;
Keywords[eu]=programa;software;gordetegi;pakete;instalatu;kendu;eguneratu;appak;aplikazioak;
Keywords[fi]=program;software;repository;package;install;remove;update;apps;applications;ohjelma;ohjelmisto;ohjelmalähde;lähteet;arkisto;paketti;asenna;poista;päivitä;sovellukset;
Keywords[fr]=programme ; logiciel ; dépôt ; archive ; paquet ; installation ; suppression ; mise à jour ; deb
Keywords[gl]=aplicativo;software;repositorio;paquete;instalar;desinstalar;actualizar;deb;
Keywords[he]=program;software;repository;package;install;remove;update;apps;applications;תוכנות;התקנה;הסרה;חבילה;מקורות;יישומים;
Keywords[hu]=program;szoftver;tároló;csomag;telepítés;eltávolítás;frissítés;alkalmazás;alkalmazások;
Keywords[id]=program;software;repositori;paket;pasang;copot;perbarui;apl;aplikasi;
Keywords[it]=programma;software;deposito;pacchetto;installa;rimuovi;aggiorna;app;applicazioni;
Keywords[ko]=program;software;repository;archive;package;install;remove;update;deb;프로그램;소프트웨어;저장소;리포지토리;패키지;꾸러미;설치;삭제;업데이트;
Keywords[nb]=program;programvare;pakkebrønn;pakke;installere;fjerne;oppdatere;app;apper;
Keywords[nl]=programma;software;opslagruimte;pakket;installeren;verwijderen;bijwerken;apps;toepassingen;applicaties;
Keywords[nn]=program;programvare;pakkebrønn;pakke;pakkar;installera;installering;fjerna;fjerning;oppdatera;oppdatering;app;appar;applikasjonar;
Keywords[pl]=program,oprogramowanie,repozytorium,archiwum,pakiet,paczka,instaluj,zainstaluj,usuń,odinstaluj,uaktualnij,aktualizuj,programy,aplikacje,deb
Keywords[pt]=programa;software;repositório;pacote;instalar;remover;actualizar;aplicações;
Keywords[pt_BR]=programa;software;repositório;pacote;instalar;instalação;remover;atualizar;aplicativos;apps;aplicações;
Keywords[ru]=program;software;repository;package;install;remove;update;apps;applications;программа;приложение;репозиторий;пакет;установка;удаление;deb;
Keywords[sk]=program;softvér;repozitár;archív;balík;inštalácia;odstránenie;appky;aplikácie;aktualizácia;
Keywords[sl]=program;programska oprema;skladišče;paket;namesti;odstrani;posodobi;programi;
Keywords[sr]=program;software;repository;package;install;remove;update;apps;applications;програм;софтвер;ризница;пакет;инсталирати;уклонити;ажурирати;
Keywords[sr@ijekavian]=program;software;repository;package;install;remove;update;apps;applications;програм;софтвер;ризница;пакет;инсталирати;уклонити;ажурирати;
Keywords[sr@ijekavianlatin]=program;software;repository;package;install;remove;update;apps;applications;program;softver;riznica;paket;instalirati;ukloniti;ažurirati;
Keywords[sr@latin]=program;software;repository;package;install;remove;update;apps;applications;program;softver;riznica;paket;instalirati;ukloniti;ažurirati;
Keywords[sv]=program;programvara;arkiv;paket;installera;ta bort;uppdatera;appar;program;
Keywords[tr]=program;yazılım;depo;paket;yükle;kur;kaldır;güncelle;uygulama;uygulamalar;
Keywords[uk]=program;software;repository;package;install;remove;update;app;apps;applications;програма;програмне забезпечення;сховище;архів;пакунок;встановити;встановлення;вилучити;вилучення;оновлення;оновити;
Keywords[x-test]=xxprogramxx;xxsoftwarexx;xxrepositoryxx;xxpackagexx;xxinstallxx;xxremovexx;xxupdatexx;xxappsxx;xxapplicationsxx;
Keywords[zh_CN]=program;software;repository;package;install;remove;update;apps;applications;程序;软件;软件源;包;安装;移除;更新;应用程序;应用;
Keywords[zh_TW]=program;software;repository;package;install;remove;update;apps;applications;

==> discover-5.11.5.tar.xz: discover-5.11.5/discover/org.kde.discover.desktop.cmake <==
[Desktop Entry]
Name=Discover
Name[ar]=استكشف
Name[ast]=Discover
Name[ca]=Discover
Name[ca@valencia]=Discover
Name[da]=Opdagelse
Name[de]=Discover
Name[el]=Discover
Name[en_GB]=Discover
Name[es]=Discover
Name[et]=Avastusretk
Name[eu]=Discover
Name[fi]=Discover
Name[fr]=Discover
Name[gl]=Descubrir
Name[he]=מרכז התוכנות Discover
Name[hu]=Discover
Name[ia]=Discoperi
Name[id]=Discover
Name[it]=Discover
Name[ko]=발견
Name[nl]=Ontdekken
Name[nn]=Oppdag
Name[pa]=ਖੋਜ
Name[pl]=Odkrywca
Name[pt]=Discover
Name[pt_BR]=Discover
Name[ru]=Discover
Name[sk]=Objaviť
Name[sl]=Programsko središče
Name[sr]=Oткривач
Name[sr@ijekavian]=Oткривач
Name[sr@ijekavianlatin]=Otkrivač
Name[sr@latin]=Otkrivač
Name[sv]=Upptäck
Name[tr]=Keşfet
Name[uk]=Discover
Name[x-test]=xxDiscoverxx
Name[zh_CN]=发现者
Name[zh_TW]=Discover
MimeType=@DesktopMimeType@
Exec=@DesktopExec@
Icon=plasmadiscover
Type=Application
X-DocPath=plasma-discover/index.html
InitialPreference=5
NoDisplay=@DesktopNoDisplay@
GenericName=Software Center
GenericName[ar]=مركز برمجيّات
GenericName[ca]=Centre de programari
GenericName[ca@valencia]=Centre de programari
GenericName[cs]=Centrum softwaru
GenericName[da]=Softwarecenter
GenericName[de]=Programmverwaltung
GenericName[el]=Κέντρο λογισμικού
GenericName[en_GB]=Software Centre
GenericName[es]=Centro de software
GenericName[et]=Tarkvarakeskus
GenericName[eu]=Software gunea
GenericName[fi]=Sovellusvalikoima
GenericName[fr]=Logithèque
GenericName[gl]=Centro de Software
GenericName[he]=מרכז התוכנות
GenericName[hu]=Szoftverközpont
GenericName[id]=Pusat Perangkat Lunak
GenericName[it]=Software Center
GenericName[ko]=소프트웨어 센터
GenericName[nb]=Programvaresenter
GenericName[nl]=Softwarecentrum
GenericName[nn]=Programvaresenter
GenericName[pa]=ਸਾਫਟਵੇਅਰ ਸੈਂਟਰ
GenericName[pl]=Ośrodek programów
GenericName[pt]=Centro de Aplicações
GenericName[pt_BR]=Central de aplicativos
GenericName[ru]=Центр программ
GenericName[sk]=Softwareové centum
GenericName[sl]=Programsko središče
GenericName[sr]=Софтверски центар
GenericName[sr@ijekavian]=Софтверски центар
GenericName[sr@ijekavianlatin]=Softverski centar
GenericName[sr@latin]=Softverski centar
GenericName[sv]=Programvarucentral
GenericName[tr]=Yazılım Merkezi
GenericName[uk]=Центр програм
GenericName[x-test]=xxSoftware Centerxx
GenericName[zh_CN]=软件中心
GenericName[zh_TW]=軟體中心
Categories=Qt;KDE;System;
Keywords=program;software;repository;package;install;remove;update;apps;applications;
Keywords[ar]=برنامج;برمجيّة;برمجية;مستودع;حزمة;تثبيت;إزالة;ازالة;تحديث;تطبيقات;تطبيق;
Keywords[ca]=programa;programari;repositori;paquet;instal·la;suprimeix;actualitza;apps;aplicacions;
Keywords[ca@valencia]=programa;programari;repositori;paquet;instal·la;suprimeix;actualitza;apps;aplicacions;
Keywords[cs]=program;software;repozitář;balíček;instalovat;odstranit;aktualizovat;programy;aplikace;
Keywords[da]=program;software;softwarekilde;repository;pakke;installer;fjern;opdater;apps;applikationer;
Keywords[de]=Programm;Software;Archiv;Repository;Paket;Installieren;Entfernen;Aktualisieren;Programme;Anwendungen;
Keywords[el]=πρόγραμμα;λογισμικό;αποθετήριο;πακέτο;εγκατάσταση;αφαίρεση;ενημέρωση;εφαρμογές;
Keywords[en_GB]=program;software;repository;package;install;remove;update;apps;applications;
Keywords[es]=programa;software;repositorio;paquete;instalar;eliminar;actualizar;apps;aplicaciones;
Keywords[et]=programm,rakendus,tarkvara,hoidla,pakk,pakett,paigaldamine,installimine,eemaldamine,uuendamine,rakendused,äpid;
Keywords[eu]=programa;software;gordetegi;pakete;instalatu;kendu;eguneratu;appak;aplikazioak;
Keywords[fi]=program;software;repository;package;install;remove;update;apps;applications;ohjelma;ohjelmisto;ohjelmalähde;lähteet;arkisto;paketti;asenna;poista;päivitä;sovellukset;
Keywords[fr]=programme ; logiciel ; dépôt ; archive ; paquet ; installation ; suppression ; mise à jour ; deb
Keywords[gl]=aplicativo;software;repositorio;paquete;instalar;desinstalar;actualizar;deb;
Keywords[he]=program;software;repository;package;install;remove;update;apps;applications;תוכנות;התקנה;הסרה;חבילה;מקורות;יישומים;
Keywords[hu]=program;szoftver;tároló;csomag;telepítés;eltávolítás;frissítés;alkalmazás;alkalmazások;
Keywords[id]=program;perangkat lunak;repositori;paket;pasang;copot;perbarui;apl;aplikasi;
Keywords[it]=programma;software;deposito;pacchetto;installa;rimuovi;aggiorna;app;applicazioni;
Keywords[ko]=program;software;repository;archive;package;install;remove;update;deb;프로그램;소프트웨어;저장소;리포지토리;패키지;꾸러미;설치;삭제;업데이트;
Keywords[nb]=program;programvare;pakkebrønn;pakke;installere;fjerne;oppdatere;app;apper;
Keywords[nl]=programma;software;opslagruimte;pakket;installeren;verwijderen;bijwerken;apps;toepassingen;applicaties;
Keywords[nn]=program;programvare;pakkebrønn;pakke;pakkar;installera;installering;fjerna;fjerning;oppdatera;oppdatering;app;appar;applikasjonar;
Keywords[pl]=program,oprogramowanie,repozytorium,archiwum,pakiet,paczka,instaluj,zainstaluj,usuń,odinstaluj,uaktualnij,aktualizuj,programy,aplikacje,deb
Keywords[pt]=programa;software;repositório;pacote;instalar;remover;actualizar;aplicações;
Keywords[pt_BR]=programa;software;repositório;pacote;instalar;instalação;remover;atualizar;aplicativos;apps;aplicações;
Keywords[ru]=program;software;repository;package;install;remove;update;apps;applications;программа;приложение;репозиторий;пакет;установка;удаление;deb;
Keywords[sk]=program;softvér;repozitár;archív;balík;inštalácia;odstránenie;appky;aplikácie;aktualizácia;
Keywords[sl]=program;programska oprema;skladišče;paket;namesti;odstrani;posodobi;programi;
Keywords[sr]=program;software;repository;package;install;remove;update;apps;applications;програм;софтвер;ризница;пакет;инсталирати;уклонити;ажурирати;
Keywords[sr@ijekavian]=program;software;repository;package;install;remove;update;apps;applications;програм;софтвер;ризница;пакет;инсталирати;уклонити;ажурирати;
Keywords[sr@ijekavianlatin]=program;software;repository;package;install;remove;update;apps;applications;program;softver;riznica;paket;instalirati;ukloniti;ažurirati;
Keywords[sr@latin]=program;software;repository;package;install;remove;update;apps;applications;program;softver;riznica;paket;instalirati;ukloniti;ažurirati;
Keywords[sv]=program;programvara;arkiv;paket;installera;ta bort;uppdatera;appar;program;
Keywords[tr]=program;yazılım;depo;paket;yükle;kur;kaldır;güncelle;uygulama;uygulamalar;
Keywords[uk]=program;software;repository;package;install;remove;update;app;apps;applications;програма;програмне забезпечення;сховище;архів;пакунок;встановити;встановлення;вилучити;вилучення;оновлення;оновити;
Keywords[x-test]=xxprogramxx;xxsoftwarexx;xxrepositoryxx;xxpackagexx;xxinstallxx;xxremovexx;xxupdatexx;xxappsxx;xxapplicationsxx;
Keywords[zh_CN]=program;software;repository;package;install;remove;update;apps;applications;程序;软件;软件源;包;安装;移除;更新;应用程序;应用;
Keywords[zh_TW]=program;software;repository;package;install;remove;update;apps;applications;
